==> haskell-dbus-hslogger-0.1.0.1-666.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-dbus-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dbus-hslogger
version:              0.1.0.1
visibility:           public
id:                   dbus-hslogger-0.1.0.1-2L01GAUtgrJ8oszteOxmax
key:                  dbus-hslogger-0.1.0.1-2L01GAUtgrJ8oszteOxmax
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/dbus-hslogger#readme
synopsis:             Expose a dbus server to control hslogger
description:
    Please see the README on Github at <https://github.com/IvanMalison/dbus-hslogger#readme>

category:             System
abi:                  3849ac33b719adb99dc4bf32cef0d5d8
exposed:              True
exposed-modules:      System.Log.DBus.Client System.Log.DBus.Server
hidden-modules:       Paths_dbus_hslogger
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dbus-hslogger-0.1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dbus-hslogger-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dbus-hslogger-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dbus-hslogger
hs-libraries:         HSdbus-hslogger-0.1.0.1-2L01GAUtgrJ8oszteOxmax
depends:
    base-4.18.2.1 dbus-1.3.3-11fa9uMK72Y1CHWrLdB8AG
    hslogger-1.3.2.0-H4OZ1FZbeeNMbSjFBgOfV

haddock-interfaces:
    /usr/share/doc/haskell-dbus-hslogger/html/dbus-hslogger.haddock

haddock-html:         /usr/share/doc/haskell-dbus-hslogger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dbus-hslogger-0.1.0.1-667-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-dbus-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dbus-hslogger
version:              0.1.0.1
visibility:           public
id:                   dbus-hslogger-0.1.0.1-3FfTar9xAyB5Q4vU4CTYHX
key:                  dbus-hslogger-0.1.0.1-3FfTar9xAyB5Q4vU4CTYHX
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/dbus-hslogger#readme
synopsis:             Expose a dbus server to control hslogger
description:
    Please see the README on Github at <https://github.com/IvanMalison/dbus-hslogger#readme>

category:             System
abi:                  1755dc29fe9fc48625cfd973bad9227b
exposed:              True
exposed-modules:      System.Log.DBus.Client System.Log.DBus.Server
hidden-modules:       Paths_dbus_hslogger
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dbus-hslogger-0.1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dbus-hslogger-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dbus-hslogger-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dbus-hslogger
hs-libraries:         HSdbus-hslogger-0.1.0.1-3FfTar9xAyB5Q4vU4CTYHX
depends:
    base-4.18.2.1 dbus-1.3.3-I7Q67QGi2CK1IKKmdebsoN
    hslogger-1.3.2.0-H4OZ1FZbeeNMbSjFBgOfV

haddock-interfaces:
    /usr/share/doc/haskell-dbus-hslogger/html/dbus-hslogger.haddock

haddock-html:         /usr/share/doc/haskell-dbus-hslogger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
